Summary:       Multichannel Digital Audio Workstation
Name:          ardour
Version:       2.8
Release:       1%{?dist}
Source:        http://ardour.org/files/releases/ardour-%{version}.tar.bz2
Source2:       ardour.script
Patch0:        ardour-2.8-SConstruct.patch
Patch1:        ardour-2.8-session.cc-no_stomp.patch
Patch2:        ardour-2.8-gcc44.patch
Patch3:        ardour-2.5-HOST_NOT_FOUND.patch
URL:           http://ardour.org
License:       GPLv2+
Group:         Applications/Multimedia

BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: scons, pkgconfig, libtool
BuildRequires: libxslt-devel, libgnomecanvas-devel, boost-devel
BuildRequires: alsa-lib-devel, jack-audio-connection-kit-devel
BuildRequires: liblo-devel, libusb-devel
BuildRequires: gettext >= 0.11.5
BuildRequires: libsamplerate-devel >= 0.0.13
BuildRequires: liblrdf-devel >= 0.3.1
BuildRequires: fftw-devel
BuildRequires: gtkmm24-devel >= 2.8
BuildRequires: libgnomecanvasmm26-devel >= 2.12
BuildRequires: aubio-devel
BuildRequires: libcurl-devel
BuildRequires: slv2-devel
Requires: hicolor-icon-theme

BuildRequires:    desktop-file-utils

# for upgrade path from CCRMA ardour2 packages:
Provides: ardour2 = %{version}-%{release}
Obsoletes: ardour2 < %{version}-%{release}

%description
Ardour is a multichannel hard disk recorder (HDR) and digital audio
workstation (DAW). It is capable of simultaneous recording 24 or more
channels of 32 bit audio at 48kHz. Ardour is intended to function as a
"professional" HDR system, replacing dedicated hardware solutions such
as the Mackie HDR, the Tascam 2424 and more traditional tape systems
like the Alesis ADAT series. It is also intended to provide the same
or better functionality as software systems such as ProTools,
Samplitude, Logic Audio, Nuendo and Cubase VST (we acknowledge these
and all other names as trademarks of their respective owners). It
supports MIDI Machine Control, and so can be controlled from any MMC
controller, such as the Mackie Digital 8 Bus mixer and many other
modern digital mixers.

%prep
%setup -q
%patch0 -p1 -b .SConstruct
%patch1 -p1 -b .no_stomp
%patch2 -p1 -b .gcc44
%patch3 -p0 -b .host.not.found

# Fix encodings:
iconv -f ISO-8859-1 -t UTF8 ardour.1.fr > ardour.1.fr.tmp
touch -r ardour.1.fr ardour.1.fr.tmp
mv -f ardour.1.fr.tmp ardour.1.fr
iconv -f KOI8-R     -t UTF8 ardour.1.ru > ardour.1.ru.tmp
touch -r ardour.1.ru ardour.1.ru.tmp
mv -f ardour.1.ru.tmp ardour.1.ru

%build
echo "GenericName=Digital Audio Workstation" >> gtk2_ardour/ardour2.desktop.in
# <sigh> ardours SConstruct script is a mess when it comes to determining
# opt_flags, so we override the lot using the ARCH= and DIST_TARGET= options

TARGETCPU="none"

%ifarch %{ix86}
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS"
TARGETCPU="i386"
%endif
%ifarch x86_64
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS -DUSE_X86_64_ASM"
TARGETCPU="x86_64"
%endif

scons %{?_smp_mflags} PREFIX=%{_prefix} LIBDIR=%{_lib} SYSLIBS=1 \
      FREESOUND=1 \
      DIST_TARGET="${TARGETCPU}" \
      ARCH="$RPM_OPT_FLAGS $ARCH_FLAGS -ffast-math" \
      AUSTATE=1

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
scons DESTDIR=$RPM_BUILD_ROOT install

# Replace ardour2 with a script
install -dm 755 $RPM_BUILD_ROOT%{_libexecdir}
mv $RPM_BUILD_ROOT%{_bindir}/ardour2 $RPM_BUILD_ROOT%{_libexecdir}
install -pm 755 %{SOURCE2} $RPM_BUILD_ROOT%{_bindir}/ardour2

# copy icons to freedesktop locations
for s in 16 22 32 48 ; do
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${s}x${s}/apps
    cp $RPM_BUILD_ROOT%{_datadir}/ardour2/icons/ardour_icon_${s}px.png \
       $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${s}x${s}/apps/ardour2.png
done

# install the desktop entry
mv gtk2_ardour/ardour2.desktop{.in,}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
desktop-file-install --vendor fedora              \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
  gtk2_ardour/ardour2.desktop

# install mime entry
mkdir -p $RPM_BUILD_ROOT%{_datadir}/mime/packages/
install -p -m 0644 gtk2_ardour/ardour2.xml $RPM_BUILD_ROOT%{_datadir}/mime/packages/

# install the man pages
install -dm 755 $RPM_BUILD_ROOT%{_mandir}/man1/
install -p -m 0644 ardour.1 $RPM_BUILD_ROOT%{_mandir}/man1/
for lang in es fr ru ; do
  install -dm 755 $RPM_BUILD_ROOT%{_mandir}/${lang}/man1/
  install -p -m 0644 ardour.1.${lang} $RPM_BUILD_ROOT%{_mandir}/${lang}/man1/
done

%find_lang gtk2_ardour
cat gtk2_ardour.lang > ardour.lang
%find_lang libardour2
cat libardour2.lang >> ardour.lang
%find_lang libgtkmm2ext
cat libgtkmm2ext.lang >> ardour.lang

%clean
rm -rf $RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null
update-desktop-database &> /dev/null
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null
fi
update-desktop-database &> /dev/null
update-mime-database %{_datadir}/mime &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f ardour.lang
%defattr(-,root,root,-)
%doc README COPYING
%config(noreplace) %{_sysconfdir}/ardour2
%{_bindir}/ardour2
%{_libexecdir}/ardour2
%{_libdir}/ardour2/
%{_datadir}/ardour2/
%{_datadir}/icons/hicolor/*/apps/ardour2.png
%{_datadir}/applications/fedora-ardour2.desktop
%{_datadir}/mime/packages/ardour2.xml
%{_mandir}/man1/ardour.1*
%{_mandir}/es/man1/ardour.1*
%{_mandir}/fr/man1/ardour.1*
%{_mandir}/ru/man1/ardour.1*

%changelog
* Mon Mar 30 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 2.8-1
- New upstream release 2.8.
- Update scriptlets according to the new guidelines
- Enable SLV2 support
- Include mime type
- Minor fixes in the SPEC file

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 22 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 2.7.1-1
- New upstream release 2.7.1.
- Replace gcc43 patch with a gcc44 patch
- Add GenericName to the .desktop file
- Fix encodings of French and Russian manpages

* Fri Nov 21 2008 Anthony Green <green@redhat.com> 2.7-1
- New upstream release 2.7.

* Mon Oct 27 2008 Anthony Green <green@redhat.com> 2.6.1-1
- New upstream release 2.6.1.

* Sat Oct 25 2008 Anthony Green <green@redhat.com> 2.6-3
- BuildRequire libcurl-devel.

* Sat Oct 25 2008 Anthony Green <green@redhat.com> 2.6-2
- Upgrade gcc43 patch to apply with fuzz = 0.

* Sat Oct 25 2008 Anthony Green <green@redhat.com> 2.6-1
- New upstream release 2.6.
- Update SConstruct patch.

* Sun Sep 21 2008 Anthony Green <green@redhat.com> 2.5-2
- Add HOST_NOT_FOUND patch.

* Thu Jul 10 2008 Anthony Green <green@redhat.com> 2.5-1
- New upstream release 2.5.

* Thu Apr 10 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 2.4.1-1
- New upstream release 2.4.1

* Mon Apr  7 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 2.4-1
- New upstream release 2.4
- Fix building with gcc-4.3, patch by Christopher Aillon (bz 434119, 440933)
- Switch to using system libraries, as the included ones don't compile with
  gcc-4.3 (bz 339391)

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.2-4
- Autorebuild for GCC 4.3

* Wed Jan 23 2008 Anthony Green <green@redhat.com> 2.2-3
- Fix tagging glitch.

* Tue Jan 22 2008 Anthony Green <green@redhat.com> 2.2-2
- Fix wrapper script.

* Thu Jan 17 2008 Anthony Green <green@redhat.com> 2.2-1
- Upgrade to ardour 2.2.  Wrap executable in a script.

* Fri Dec 21 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-4
- Fix building of ardour on alpha machines (bz 425987)
- Fix building with glib-2.15.0

* Wed Oct 10 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-3
- Fix finding of translations (bz 238552)
- Convert some documentation files to UTF-8

* Tue Oct  9 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-2
- Upgrade to latest upstream 2.1 (bz 238552)
- Merge with CCRMA ardour2 package
- Begin with a release of 2 to be higher then CCRMA's last EVR

* Wed May 02 2007 Anthony Green <green@redhat.com> 2.0-1
- Upgrade sources.

* Sat Jan 06 2007 Anthony Green <green@redhat.com> 0.99.3-8
- Enable optimization (oops).
- Add ardour-no-sse.patch to disable use of build-system dependent 
  hardware features (SSE, MMX, etc).

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 0.99.3-7
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 19 2006 Anthony Green <green@redhat.com> 0.99.3-6
- Fix release tag.

* Mon Sep 18 2006 Anthony Green <green@redhat.com> 0.99.3-5.1
- Rebuild.

* Sat Sep  8 2006 Anthony Green <green@redhat.com> 0.99.3-5
- Install the templates.

* Sat Sep  2 2006 Anthony Green <green@redhat.com> 0.99.3-4
- Move .desktop file out of spec file to source dir.
- Add a couple of upstream patches (2 and 3)

* Sun Aug 13 2006 Anthony Green <green@redhat.com> 0.99.3-3
- Remove PlanetCCRMA changelogs (rpmlint was complaining)
- Escape macros in changelog.
- Remove useless rm in %%build section.
- Don't install useless README file.
- Clean up BuildRequires and %%files sections.

* Sat May 13 2006 Anthony Green <green@redhat.com> 0.99.3-2
- Conditionally apply ardour-lib64-ladspa.patch.

* Sat May 13 2006 Anthony Green <green@redhat.com> 0.99.3-1
- Update sources to 0.99.3.
- Add linudoc-tools dependency.
- Set USE_SSE_EVERYWHERE and BUILD_SSE_OPTIMIZATIONS at build time.
- Replace some macro command usage.

* Sat Apr 22 2006 Anthony Green <green@redhat.com> 0.99.2-3
- Use %%find_lang.

* Thu Apr 20 2006 Anthony Green <green@redhat.com> 0.99.2-2
- Fix ardour URL.  Add scons smp build flags.
- Own %%{_sysconfdir}/ardour.
- Standardize on $RPM_BUILD_ROOT usage.
- Remove gcc BuildRequires.

* Tue Apr 18 2006 Anthony Green <green@redhat.com> 0.99.2-1
- Update sources. Build for Fedora Extras. Derived from Fernando
  Lopez-Lezcano's PlanetCCRMA package.
